==> ws-notification-definition-0.9.2-sources.jar: com/ebmwebsourcing/wsstar/notification/definition/basenotification/api/Subscribe.java <==
/**
 * Copyright (c) 2009 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $id.java
 * -------------------------------------------------------------------------
 */
package com.ebmwebsourcing.wsstar.notification.definition.basenotification.api;

import java.util.Date;

import org.ow2.easywsdl.schema.api.XMLElement;

import com.ebmwebsourcing.wsstar.addressing.definition.api.EndpointReferenceType;
import com.ebmwebsourcing.wsstar.notification.definition.utils.WSNotificationException;

public interface Subscribe extends XMLElement {
	
	public EndpointReferenceType getConsumerReference() throws WSNotificationException;
	
	public void setConsumerReference(EndpointReferenceType ref);
	
	public FilterType getFilter();
	
	public void setFilter(FilterType filter);
	
	public Date getInitialTerminationTime();
	
	public void setInitialTerminationTime(Date value) throws WSNotificationException;
	
	public SubscriptionPolicyType getSubscriptionPolicy();
	
	public void setSubscriptionPolicy(SubscriptionPolicyType policy);
	
}

==> ws-notification-definition-1.0-sources.jar: com/ebmwebsourcing/wsstar/notification/definition/basenotification/api/Subscribe.java <==
/**
 * Copyright (c) 2009 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $id.java
 * -------------------------------------------------------------------------
 */
package com.ebmwebsourcing.wsstar.notification.definition.basenotification.api;

import java.util.Date;

import javax.xml.datatype.Duration;

import org.ow2.easywsdl.schema.api.XMLElement;

import com.ebmwebsourcing.wsstar.addressing.definition.api.EndpointReferenceType;
import com.ebmwebsourcing.wsstar.notification.definition.utils.WSNotificationException;

public interface Subscribe extends XMLElement {
	
	public EndpointReferenceType getConsumerReference() throws WSNotificationException;
	
	public void setConsumerReference(EndpointReferenceType ref);
	
	public FilterType getFilter();
	
	public void setFilter(FilterType filter);
	
	public String getInitialTerminationTime() throws WSNotificationException;
	
	public void setInitialTerminationTime(Date value) throws WSNotificationException;
	
	public void setInitialTerminationTime(Duration value) throws WSNotificationException;
	
	public SubscriptionPolicyType getSubscriptionPolicy();
	
	public void setSubscriptionPolicy(SubscriptionPolicyType policy);
	
}
